@@ -16,7 +16,8 @@ Lingua::PTD::TSV - Sub-module to export PTD to TSV
 
   use Lingua::PTD;
 
-  $ptd = Lingua::PTD->new( "file.tsv" );
+  my $ptd = Lingua::PTD->new( $file );
+  $ptd->saveAs("tsv", $dest, $options);
 
 =head1 DESCRIPTION
 
@@ -37,7 +38,8 @@ Copyright (C) 2010-2012 by Alberto Manuel Brandão Simões
 =cut
 
 sub _save {
-    my ($ptd, $filename, $min) = @_;
+    my ($ptd, $filename, $my_opts) = @_;
+    my $min = $my_opts->{m} //= 0.5;
 
     open OUT, ">:utf8", $filename or return 0;
     select OUT;
